==> munit-runner-1.0.0-sources.jar: org/mule/munit/runner/MunitRunner.java <==
/*
 * Copyright (c) 2015 MuleSoft, Inc. This software is protected under international
 * copyright law. All use of this software is subject to MuleSoft's Master Subscription
 * Agreement (or other master license agreement) separately entered into in writing between
 * you and MuleSoft. If such an agreement is not in place, you may not use the software.
 */
package org.mule.munit.runner;

import org.mule.api.MuleContext;
import org.mule.api.MuleEvent;
import org.mule.api.MuleException;
import org.mule.munit.assertion.processors.MunitAfterSuite;
import org.mule.munit.assertion.processors.MunitBeforeSuite;
import org.mule.munit.assertion.processors.MunitFlow;
import org.mule.munit.runner.output.DefaultOutputHandler;
import org.mule.munit.runner.output.TestOutputHandler;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

/**
 * <p>Runs the Munit Suite</p>
 * <p/>
 * <p>T is the expected result from the suite run</p>
 *
 * @author Mulesoft Inc.
 * @since 3.3.2
 */
public abstract class MunitRunner<T> {

    private TestOutputHandler handler = new DefaultOutputHandler();
    private MuleContextManager muleContextManager = new MuleContextManager(null);

    private MuleContext muleContext;

    public MunitRunner(TestOutputHandler handler, MuleContextManager muleContextManager, MuleContext muleContext) {
        this.handler = handler;
        this.muleContextManager = muleContextManager;
        this.muleContext = muleContext;
    }

    /**
     * <p>Runs all the tests of the suite</p>
     *
     * @return The suite result
     * @throws Exception If the suite fails
     */
    protected abstract T runSuite() throws Exception;

    /**
     * <p>Get the name of the suite</p>
     *
     * @return The suite name
     */
    protected abstract String getSuiteName();

    /**
     * <p>Runs the suite based on the constructor arguments </p>
     *
     * @return The suite result
     */
    public T run() {
        try {
            handler.printTestName(getSuiteName());
            process(lookupFlows(MunitBeforeSuite.class), muleEvent());

            T result = runSuite();

            return result;

        } catch (Exception e) {
            throw new RuntimeException("Could not Run the suite", e);
        } finally {
            try {
                process(lookupFlows(MunitAfterSuite.class), muleEvent());
            } catch (MuleException e) {
                throw new RuntimeException("After Suite process could not be executed", e);
            } finally {
                muleContextManager.killMule(muleContext);
            }
        }

    }

    private MuleEvent muleEvent() {
        return MunitMuleEventBuilder.buildGenericMuleEvent(muleContext);
    }

    private void process(Collection<MunitFlow> flowConstructs, MuleEvent event) throws MuleException {
        for (MunitFlow flowConstruct : flowConstructs) {
            handler.printDescription(flowConstruct.getName(), flowConstruct.getDescription());
            (flowConstruct).process(event);
        }
    }

    private List<MunitFlow> lookupFlows(Class<? extends MunitFlow> munitClass) {
        return new ArrayList<MunitFlow>(muleContext.getRegistry()
                .lookupObjects(munitClass));
    }
}

==> munit-runner-1.1.1-sources.jar: org/mule/munit/runner/MunitRunner.java <==
/*
 * Copyright (c) 2015 MuleSoft, Inc. This software is protected under international
 * copyright law. All use of this software is subject to MuleSoft's Master Subscription
 * Agreement (or other master license agreement) separately entered into in writing between
 * you and MuleSoft. If such an agreement is not in place, you may not use the software.
 */
package org.mule.munit.runner;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.mule.api.MuleContext;
import org.mule.api.MuleEvent;
import org.mule.api.MuleException;
import org.mule.munit.assertion.processors.MunitAfterSuite;
import org.mule.munit.assertion.processors.MunitBeforeSuite;
import org.mule.munit.assertion.processors.MunitFlow;
import org.mule.munit.runner.output.DefaultOutputHandler;
import org.mule.munit.runner.output.TestOutputHandler;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

/**
 * <p>Runs the Munit Suite</p>
 * <p/>
 * <p>T is the expected result from the suite run</p>
 *
 * @author Mulesoft Inc.
 * @since 3.3.2
 */
public abstract class MunitRunner<T> {
    private transient Log logger = LogFactory.getLog(this.getClass());

    private TestOutputHandler handler = new DefaultOutputHandler();
    private MuleContextManager muleContextManager = new MuleContextManager(null);

    private MuleContext muleContext;

    public MunitRunner(TestOutputHandler handler, MuleContextManager muleContextManager, MuleContext muleContext) {
        this.handler = handler;
        this.muleContextManager = muleContextManager;
        this.muleContext = muleContext;
    }

    /**
     * <p>Runs all the tests of the suite</p>
     *
     * @return The suite result
     * @throws Exception If the suite fails
     */
    protected abstract T runSuite() throws Exception;

    /**
     * <p>Get the name of the suite</p>
     *
     * @return The suite name
     */
    protected abstract String getSuiteName();

    /**
     * <p>Runs the suite based on the constructor arguments </p>
     *
     * @return The suite result
     */
    public T run() {
        try {
            logger.debug("About to run MUnit suite: " + getSuiteName() + " ...");
            handler.printTestName(getSuiteName());

            logger.debug("Executing Before Suite scopes...");
            process(lookupFlows(MunitBeforeSuite.class), muleEvent());

            T result = runSuite();

            logger.debug("Tests in MUnit suite: " + getSuiteName() + " run");
            return result;

        } catch (Exception e) {
            logger.error("Could not Run the suite: " + getSuiteName(), e);
            throw new RuntimeException("Could not Run the suite", e);
        } finally {
            try {
                logger.debug("Executing After Suite scopes...");

                process(lookupFlows(MunitAfterSuite.class), muleEvent());
            } catch (MuleException e) {
                logger.error("Could not execute After suites", e);
                throw new RuntimeException("After Suite process could not be executed", e);
            } finally {
                muleContextManager.killMule(muleContext);
            }
        }

    }

    private MuleEvent muleEvent() {
        return MunitMuleEventBuilder.buildGenericMuleEvent(muleContext);
    }

    private void process(Collection<MunitFlow> flowConstructs, MuleEvent event) throws MuleException {
        for (MunitFlow flowConstruct : flowConstructs) {
            handler.printDescription(flowConstruct.getName(), flowConstruct.getDescription());
            (flowConstruct).process(event);
        }
    }

    private List<MunitFlow> lookupFlows(Class<? extends MunitFlow> munitClass) {
        return new ArrayList<MunitFlow>(muleContext.getRegistry()
                .lookupObjects(munitClass));
    }
}
